=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-07-01 19:03:33 +0000
+++ bzrlib/commands.py	2006-07-14 05:02:37 +0000
@@ -44,7 +44,7 @@
 import bzrlib.osutils
 from bzrlib.revisionspec import RevisionSpec
 from bzrlib.symbol_versioning import (deprecated_method, zero_eight)
-from bzrlib import trace
+import bzrlib.trace
 from bzrlib.trace import mutter, note, log_error, warning, be_quiet
 
 plugin_cmds = {}

=== modified file 'bzrlib/tests/test_revisiontree.py'
--- bzrlib/tests/test_revisiontree.py	2006-06-16 15:25:15 +0000
+++ bzrlib/tests/test_revisiontree.py	2006-07-14 05:02:37 +0000
@@ -47,4 +47,3 @@
             [self.rev_id],
             self.t.branch.repository.revision_tree(revid_2).get_parent_ids())
         # TODO commit a merge and check it is reported correctly.
-        

=== modified file 'bzrlib/tests/test_status.py'
--- bzrlib/tests/test_status.py	2006-05-17 12:52:17 +0000
+++ bzrlib/tests/test_status.py	2006-07-14 05:02:37 +0000
@@ -17,20 +17,30 @@
 
 from StringIO import StringIO
 
-from bzrlib.bzrdir import BzrDir
-from bzrlib.status import show_pending_merges
-from bzrlib.tests import TestCaseInTempDir
-
-
-class TestStatus(TestCaseInTempDir):
+from bzrlib.revisionspec import RevisionSpec
+from bzrlib.status import show_pending_merges, show_tree_status
+from bzrlib.tests import TestCaseWithTransport
+
+
+class TestStatus(TestCaseWithTransport):
 
     def test_pending_none(self):
         # Test whether show_pending_merges works in a tree with no commits
-        tree = BzrDir.create_standalone_workingtree('a')
+        tree = self.make_branch_and_tree('a')
         tree.commit('empty commit')
-        tree2 = BzrDir.create_standalone_workingtree('b')
+        tree2 = self.make_branch_and_tree('b')
         tree2.branch.fetch(tree.branch)
         tree2.set_pending_merges([tree.last_revision()])
         output = StringIO()
         show_pending_merges(tree2, output)
         self.assertContainsRe(output.getvalue(), 'empty commit')
+
+    def tests_revision_to_revision(self):
+        """doing a status between two revision trees should work."""
+        tree = self.make_branch_and_tree('.')
+        r1_id = tree.commit('one', allow_pointless=True)
+        r2_id = tree.commit('two', allow_pointless=True)
+        r2_tree = tree.branch.repository.revision_tree(r2_id)
+        output = StringIO()
+        show_tree_status(tree, to_file=output, revision=[RevisionSpec("revid:%s" % r1_id), RevisionSpec("revid:%s" % r2_id)])
+        # return does not matter as long as it did not raise.

